@@ -150,15 +150,15 @@ bool kvi_stringIpToBinaryIp(const char *szIp,struct in_addr *address)
 
 {
 
-	register unsigned long val;
+	unsigned long val;
 
-	register int base, n;
+	int base, n;
 
-	register char c;
+	char c;
 
 	unsigned int parts[4];
 
-	register unsigned int *pp = parts;
+	unsigned int *pp = parts;
 
 	if(!szIp)return false;
 
@@ -650,9 +650,9 @@ static unsigned int i2a(char* dest,unsigned int x)
 
 {
 
-  register unsigned int tmp=x;
+  unsigned int tmp=x;
 
-  register unsigned int len=0;
+  unsigned int len=0;
 
   if (x>=100) { *dest++=tmp/100+'0'; tmp=tmp%100; ++len; }
 
