@@ -316,7 +316,7 @@ KviBoolOption g_boolOptionsTable[KVI_NUM_BOOL_OPTIONS]=
 #ifdef COMPILE_ON_WINDOWS
 	#define RUN_THE_BROWSER "run \"cmd.exe /c start \\\"\\\" \\\"$0\\\"\""
 #else
-	#ifdef COMPILE_KDE_SUPPORT
+	#ifdef COMPILE_TDE_SUPPORT
 		#define RUN_THE_BROWSER "run kfmclient openURL $0"
 	#else
 		#ifdef Q_OS_MACX
