@@ -640,7 +640,7 @@ bool KviKvsObject_painter::functiondrawArc(KviKvsObjectFunctionCall *c)
 	kvs_int_t iSangle,iLena,iX,iY,iW,iH;
 	KVSO_PARAMETERS_BEGIN(c)
 		KVSO_PARAMETER("start_angle",KVS_PT_INT,0,iSangle)
-		KVSO_PARAMETER("a_lenght",KVS_PT_INT,0,iLena)
+		KVSO_PARAMETER("a_length",KVS_PT_INT,0,iLena)
 		KVSO_PARAMETER("x_or_array",KVS_PT_VARIANT,0,pXOrArray)
 		KVSO_PARAMETER("y",KVS_PT_INT,KVS_PF_OPTIONAL,iY)
 		KVSO_PARAMETER("w",KVS_PT_INT,KVS_PF_OPTIONAL,iW)
@@ -658,7 +658,7 @@ bool KviKvsObject_painter::functiondrawChord(KviKvsObjectFunctionCall *c)
 	kvs_int_t iSangle,iLena,iX,iY,iW,iH;
 	KVSO_PARAMETERS_BEGIN(c)
 		KVSO_PARAMETER("start_angle",KVS_PT_INT,0,iSangle)
-		KVSO_PARAMETER("a_lenght",KVS_PT_INT,0,iLena)
+		KVSO_PARAMETER("a_length",KVS_PT_INT,0,iLena)
 		KVSO_PARAMETER("x_or_array",KVS_PT_VARIANT,0,pXOrArray)
 		KVSO_PARAMETER("y",KVS_PT_INT,KVS_PF_OPTIONAL,iY)
 		KVSO_PARAMETER("w",KVS_PT_INT,KVS_PF_OPTIONAL,iW)
@@ -717,7 +717,7 @@ bool KviKvsObject_painter::functiondrawPie(KviKvsObjectFunctionCall *c)
 	kvs_int_t iSangle,iLena,iX,iY,iW,iH;
 	KVSO_PARAMETERS_BEGIN(c)
 		KVSO_PARAMETER("start_angle",KVS_PT_INT,0,iSangle)
-		KVSO_PARAMETER("a_lenght",KVS_PT_INT,0,iLena)
+		KVSO_PARAMETER("a_length",KVS_PT_INT,0,iLena)
 		KVSO_PARAMETER("x_or_array",KVS_PT_VARIANT,0,pXOrArray)
 		KVSO_PARAMETER("y",KVS_PT_INT,KVS_PF_OPTIONAL,iY)
 		KVSO_PARAMETER("w",KVS_PT_INT,KVS_PF_OPTIONAL,iW)
