@@ -105,10 +105,10 @@ const int widgettypes_cod[] = {
 
 #ifdef COMPILE_USE_QT4
 
-	#define TQT_WIDGET_TABFOCUS TTQ_TabFocus
-	#define	TQT_WIDGET_CLICKFOCUS TTQ_ClickFocus
-	#define TQT_WIDGET_STRONGFOCUS TTQ_StrongFocus
-	#define TQT_WIDGET_NOFOCUS TTQ_NoFocus
+	#define TQT_WIDGET_TABFOCUS TQ_TabFocus
+	#define	TQT_WIDGET_CLICKFOCUS TQ_ClickFocus
+	#define TQT_WIDGET_STRONGFOCUS TQ_StrongFocus
+	#define TQT_WIDGET_NOFOCUS TQ_NoFocus
 
 #else
 	#define TQT_WIDGET_TABFOCUS TQ_TabFocus
