@@ -596,7 +596,7 @@ static bool system_kvs_fnc_dcop(KviKvsModuleFunctionCall *c)
 	}
 #else
 	if(!bTestMode)
-		c->warning(__tr2qs("DCOP calls are available only when KDE support is compiled in"));
+		c->warning(__tr2qs("DCOP calls are available only when TDE support is compiled in"));
 	c->returnValue()->setInteger(0);
 #endif
 
