@@ -42,7 +42,7 @@ TORR_IMPLEMENT_DESCRIPTOR(
 	KviKTorrentDCOPInterface,
 	"ktorrentdcop",
 	__tr2qs_ctx(
-		"An interface to KDE's excellent KTorrent client.\n" \
+		"An interface to TDE's excellent KTorrent client.\n" \
 		"Download it from http://www.ktorrent.org\n",
 		"torrent"
 	)
